@@ -22,31 +22,63 @@
 
 This AWS Solutions Construct implements an Amazon S3 bucket connected to an AWS Lambda function.
 
-Here is a minimal deployable pattern definition in Typescript:
+Here is a minimal deployable pattern definition:
+
+Typescript
 
 ```python
+import { Construct } from 'constructs';
+import { Stack, StackProps } from 'aws-cdk-lib';
+import * as lambda from "aws-cdk-lib/aws-lambda";
 import { S3ToLambdaProps, S3ToLambda } from '@aws-solutions-constructs/aws-s3-lambda';
 
 new S3ToLambda(this, 'test-s3-lambda', {
-    lambdaFunctionProps: {
-        code: lambda.Code.fromAsset(`${__dirname}/lambda`),
-        runtime: lambda.Runtime.NODEJS_14_X,
-        handler: 'index.handler'
-    },
+  lambdaFunctionProps: {
+    code: lambda.Code.fromAsset(`lambda`),
+    runtime: lambda.Runtime.NODEJS_14_X,
+    handler: 'index.handler'
+  },
 });
 ```
 
-## Initializer
+Python
 
-```text
-new S3ToLambda(scope: Construct, id: string, props: S3ToLambdaProps);
+```python
+from aws_solutions_constructs.aws_s3_lambda import S3ToLambda
+from aws_cdk import (
+    aws_lambda as _lambda,
+    Stack
+)
+from constructs import Construct
+
+S3ToLambda(self, 'test_s3_lambda',
+           lambda_function_props=_lambda.FunctionProps(
+               code=_lambda.Code.from_asset('lambda'),
+               runtime=_lambda.Runtime.PYTHON_3_9,
+               handler='index.handler'
+           )
+           )
 ```
 
-*Parameters*
+Java
 
-* scope [`Construct`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_core.Construct.html)
-* id `string`
-* props [`S3ToLambdaProps`](#pattern-construct-props)
+```java
+import software.constructs.Construct;
+
+import software.amazon.awscdk.Stack;
+import software.amazon.awscdk.StackProps;
+import software.amazon.awscdk.services.lambda.*;
+import software.amazon.awscdk.services.lambda.Runtime;
+import software.amazon.awsconstructs.services.s3lambda.*;
+
+new S3ToLambda(this, "test-s3-lambda'", new S3ToLambdaProps.Builder()
+        .lambdaFunctionProps(new FunctionProps.Builder()
+                .runtime(Runtime.NODEJS_14_X)
+                .code(Code.fromAsset("lambda"))
+                .handler("index.handler")
+                .build())
+        .build());
+```
 
 ## Pattern Construct Props
 
